Rdocumentation
powered by
Learn R Programming
graphhopper (version 0.1.2)
gh_available_spt_columns: Get a vector with available columns of the spt endpoint
Description
Get a vector with available columns of the spt endpoint
Usage
gh_available_spt_columns()
Arguments